<template>
  <div class="app-container">
    <el-form
      class="responsive-form"
      :model="queryParams"
      ref="queryRef"
      :inline="true"
      v-show="showSearch"
      :label-width="locale == 'zh' ? '110px' : '200px'"
    >
      <el-form-item :label="$t('plan.query.workOrderNo')" prop="workOrderNo">
        <el-input
          :style="{ width: locale == 'zh' ? '200px' : '280px' }"
          v-model="queryParams.workOrderNo"
          :placeholder="`${$t('common.common.placeholder')}${$t(
            'plan.query.workOrderNo'
          )}`"
          clearable
          @keyup.enter="handleQuery"
        />
      </el-form-item>
      <!-- <el-row type="flex" justify="left">
        <el-col :span="5"> -->
      <el-form-item
        :label="$t('plan.query.requireTraceID')"
        prop="requireTraceId"
      >
        <el-input
          :style="{ width: locale == 'zh' ? '200px' : '280px' }"
          v-model="queryParams.requireTraceId"
          :placeholder="`${$t('common.common.placeholder')}${$t(
            'plan.query.requireTraceID'
          )}`"
          clearable
          @keyup.enter="handleQuery"
        />
      </el-form-item>
      <!-- </el-col>
        <el-col :span="5"> -->
      <el-form-item :label="$t('plan.query.itemNumber')" prop="mainPartNumber">
        <el-input
          :style="{ width: locale == 'zh' ? '200px' : '280px' }"
          v-model="queryParams.mainPartNumber"
          :placeholder="`${$t('common.common.placeholder')}${$t(
            'plan.query.itemNumber'
          )}`"
          clearable
          @keyup.enter="handleQuery"
        />
      </el-form-item>
      <el-form-item
        :label="$t('plan.table.delayRiskIdentification')"
        prop="hasDelayRisk"
      >
        <el-input
          :style="{ width: locale == 'zh' ? '200px' : '280px' }"
          v-model="queryParams.hasDelayRisk"
          :placeholder="`${$t('common.common.placeholder')}${$t(
            'plan.table.delayRiskIdentification'
          )}`"
          clearable
          @keyup.enter="handleQuery"
        />
      </el-form-item>
      <!-- </el-col>
        <el-col :span="14" style="text-align: right"> -->
      <el-form-item class="column-with-margin">
        <el-button type="primary" icon="Search" @click="handleQuery">{{
          $t("common.common.query")
        }}</el-button>
        <el-button icon="Refresh" @click="resetQuery">{{
          $t("common.common.reset")
        }}</el-button>
      </el-form-item>
      <!-- </el-col>
      </el-row> -->
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="Plus"
          :disabled="multiple"
          @click="handleBatchUpdatePlanDate"
          v-hasPermi="['apsPlatePlan:edit']"
          >{{ $t("plan.btns.batchUpdateOrderDate") }}</el-button
        >
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="Edit"
          @click="handleGenerateList"
          v-hasPermi="['apsPlatePlan:edit']"
          >{{ $t("plan.btns.generatePlanOrder") }}</el-button
        >
      </el-col>
      <right-toolbar
        v-model:showSearch="showSearch"
        @queryTable="getList"
      ></right-toolbar>
    </el-row>
    <HxlhTable
      style="width: 100%"
      :columns="columns"
      :data="orderList"
      :loading="loading"
      :height="height"
      ref="tableRef"
      :page="page"
      @changePageNo="changePageNo"
      @changePageSize="changePageSize"
      @on-checkbox="handleCheckboxChange"
    >
      <template #buttons="{ row }">
        <el-button
          type="primary"
          link
          @click="handleCheckView(row)"
          v-hasPermi="['aps:calendar:update']"
          >{{ $t("plan.btns.viewRequirement") }}</el-button
        >
      </template>
    </HxlhTable>
    <el-dialog
      :title="$t('plan.title.viewAssociatedRequirements')"
      v-model="openDialog"
      width="900px"
      append-to-body
    >
      <HxlhTable
        style="width: 100%"
        :columns="subGridOptions"
        :data="subList"
        :loading="loadingSub"
        :height="heightSub"
      >
      </HxlhTable>
      <template #footer>
        <span class="dialog-footer">
          <el-button @click="openDialog = false">{{
            $t("common.common.cancel")
          }}</el-button>
        </span>
      </template>
    </el-dialog>
    <el-dialog
      :title="$t('plan.btns.batchUpdateOrderDate')"
      v-model="openBatchDialog"
      width="900px"
      append-to-body
    >
      <div class="mode_box">
        <span>{{ $t("plan.title.setMode") }}</span>
        <el-radio-group v-model="radio">
          <el-radio :label="1">{{
            $t("plan.btns.batchUpdateOrderDate")
          }}</el-radio>
          <el-radio :label="2">{{
            $t("plan.title.CustomizePlannedCompletionDate")
          }}</el-radio>
        </el-radio-group>
      </div>
      <div class="red_color">{{ $t("plan.title.tipsBugSheetMetal") }}</div>
      <div class="mode_box" v-if="radio === 2">
        <span>{{ $t("plan.title.CustomizePlannedCompletionDate") }}</span>
        <el-date-picker
          v-model="value4"
          type="dates"
          :placeholder="$t('plan.title.CustomizePlannedCompletionDate')"
        />
      </div>
      <HxlhTable
        v-if="radio === 1"
        style="width: 100%"
        :columns="subUpdateGridOptions"
        :data="subUpdateList"
        :loading="loading"
        :height="heightSub"
      >
      </HxlhTable>
      <HxlhTable
        v-if="radio === 2"
        style="width: 100%"
        :columns="subUpdateCustomGridOptions"
        :data="subUpdateList"
        :loading="loading"
        :height="heightSub"
      >
      </HxlhTable>
      <template #footer>
        <span class="dialog-footer">
          <el-button @click="openBatchDialog = false">{{
            $t("common.common.cancel")
          }}</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="Calendar">
import HxlhTable from "@/components/HxlhTable";
import useBasicStore from "@/store/modules/request/basic/page";
import { listAll_plant } from "@/api/basicData/plant";
import { metalOrderManageList,metalOrderManageSubList,generatorPlanList } from "@/api/mainPlan/metalOrderManage.js";
import { useI18n } from "vue-i18n"; //要在js中使用国际化
const { t, locale } = useI18n();
const basicStore = useBasicStore();
const { proxy } = getCurrentInstance();
const radio = ref(1);
const openDialog = ref(false);
const openBatchDialog = ref(false);
const subGridOptions = ref([]);
const subUpdateGridOptions = ref([]);
const subUpdateCustomGridOptions = ref([]);
const subList = ref([]);
const subUpdateList = ref([]);
// const tableRef = ref();
const orderList = ref([]);
const loading = ref(false);
const loadingSub = ref(false)
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");
const data = reactive({
  form: {
    type: "1",
  },
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    workOrderNo: null,
    requireTraceId: null,
    mainPartNumber: null,
    hasDelayRisk: null,
  },
});
const { queryParams, form, rules } = toRefs(data);
const plantList = ref([]);
const shopList = ref([]);
const allShopList = ref([]);
const processList = ref([]);
const height = ref(document.documentElement.clientHeight - 270 + "px;");
// 表格配置-列表
const columns = ref([]);
// 分页属性
const page = ref({
  total: 0,
  current: 1,
  size: 10,
});
watch(
  locale,
  (newLocale) => {
    columns.value = [
      { type: "checkbox", width: 60, align: "center" },
      {
        title: t("basic.table.requirementID"),
        field: "requireId",
        width: 150,
        align: "center",
      },
      {
        title: t("basic.table.requirementTraceabilityID"),
        field: "requireTraceId",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.workOrderNo"),
        field: "workOrderNo",
        width: 200,
        align: "center",
      },
      {
        title: t("basic.table.matchQuantity"),
        field: "deductionAmount",
        width: 200,
        align: "center",
      },
      {
        title: t("basic.table.workOrderType"),
        field: "workOrderType",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.itemNumber"),
        field: "mainPartNumber",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.mainPartDrawingNumber"),
        field: "mainPartDrawingNumber",
        width: 200,
        align: "center",
      },
      {
        title: t("basic.table.mainCustomer"),
        field: "customer",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.productionQuantity"),
        field: "productionQuantity",
        width: 100,
        align: "center",
      },
      {
        title: t("basic.table.applicableFactories"),
        field: "applicableFactories",
        width: 200,
        align: "center",
        formatter: ({ cellValue, row, column }) => {
          if (cellValue) {
            for (let i = 0; i < plantList.value.length; i++) {
              if (cellValue === plantList.value[i].plantCode) {
                return plantList.value[i].plantName;
              }
            }
          }
        },
      },
      {
        title: t("plan.table.productionBase"),
        field: "productionBase",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.planStartDay"),
        field: "planStartDay",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.planEndDayDate"),
        field: "planEndDay",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.workorderCreationTime"),
        field: "orderCreateTime",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.mismatchedProductionQuantity"),
        field: "unmatchedQuantity",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.delayRiskIdentification"),
        field: "hasDelayRisk",
        width: 100,
        align: "center",
      },
      {
        title: t("common.common.operate"),
        width: 100,
        fixed: "right",
        slots: { default: "buttons" },
        align: "center",
      },
    ];
    subGridOptions.value = [
      {
        title: t("basic.table.requirementID"),
        field: "id",
        width: 150,
        align: "center",
      },
      {
        title: t("basic.table.requirementTraceabilityID"),
        field: "requireId",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.itemNumber"),
        field: "bomLineCode",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.bomLowCode"),
        field: "bomLineLevel",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.bomUsage"),
        field: "bomUseAmount",
        width: 200,
        align: "center",
      },
      {
        title: t("basic.table.processRouteID"),
        field: "processRouteId",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.processRouteWorkingHours"),
        field: "processRouteHours",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.demandQuantity"),
        field: "requireAmount",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.netRequirement"),
        field: "netRequirement",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.planStartDay"),
        field: "startDate",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.planEndDayDate"),
        field: "completeDate",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.requirementDate"),
        field: "demandDate",
        width: 100,
        align: "center",
      },
      {
        title: t("basic.table.applicableFactories"),
        field: "orgCode",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.productionBase"),
        field: "productionBase",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.matchState"),
        field: "matchState",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.matchPattern"),
        field: "matchMode",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.unmatchedDemandQuantity"),
        field: "unmatchedDemandAmount",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.suggestedCompletionDate"),
        field: "suggestedCompletionDate",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.delayRiskIdentification"),
        field: "hasDelayRisk",
        width: 100,
        align: "center",
      },
    ];
    subUpdateGridOptions.value = [
      {
        title: t("basic.table.requirementID"),
        field: "requireId",
        width: 150,
        align: "center",
      },
      {
        title: t("basic.table.requirementTraceabilityID"),
        field: "requireTraceId",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.workOrderNo"),
        field: "workOrderNo",
        width: 200,
        align: "center",
      },
      {
        title: t("basic.table.matchQuantity"),
        field: "deductionAmount",
        width: 200,
        align: "center",
      },
      {
        title: t("basic.table.workOrderType"),
        field: "workOrderType",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.itemNumber"),
        field: "mainPartNumber",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.planStartDay"),
        field: "planStartDay",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.planEndDayDate"),
        field: "planEndDay",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.startDateOfDemandPlan"),
        field: "startDay",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.requirementPlanCompletionDate"),
        field: "completeDay",
        width: 100,
        align: "center",
      },
    ];
    subUpdateCustomGridOptions.value = [
      {
        title: t("basic.table.requirementID"),
        field: "requireId",
        width: 150,
        align: "center",
      },
      {
        title: t("basic.table.requirementTraceabilityID"),
        field: "requireTraceId",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.workOrderNo"),
        field: "workOrderNo",
        width: 200,
        align: "center",
      },
      {
        title: t("basic.table.matchQuantity"),
        field: "deductionAmount",
        width: 200,
        align: "center",
      },
      {
        title: t("basic.table.workOrderType"),
        field: "workOrderType",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.itemNumber"),
        field: "mainPartNumber",
        width: 200,
        align: "center",
      },
      {
        title: t("plan.table.planStartDay"),
        field: "planStartDay",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.planEndDayDate"),
        field: "planEndDay",
        width: 100,
        align: "center",
      },
      {
        title: t("plan.table.customizePlannedCompletionDate"),
        field: "updateTime",
        width: 100,
        align: "center",
      },
    ];
  },
  {
    immediate: true,
    deep: true,
  }
);
function handleBatchUpdatePlanDate() {
  openBatchDialog.value = true;
}
function handleCheckView(row) {
  openDialog.value = true;
  loadingSub.value = true;
  metalOrderManageSubList(row.workOrderNo).then((res)=>{
    subList.value = res;
    loadingSub.value = false;
    console.log(res,"metalOrderManageSubListmetalOrderManageSubList")
  }).catch(()=>{
    loadingSub.value = false;
  })
}
async function handleGenerateList(){
  await generatorPlanList()
}
/** 查询钣金工单计划管理列表 */
function getList() {
  loading.value = true;
  if (basicStore.sheetMetalOrderManageList&&basicStore.sheetMetalOrderManageList.rows) {
    orderList.value = basicStore.sheetMetalOrderManageList.rows;
    loading.value = false;
  } else {
    basicStore.getMetalOrderManagerList(queryParams.value).then((response) => {
      orderList.value = response.rows;
      page.value.total = response.total;
      loading.value = false;
    }).catch(()=>{
      loading.value = false;
    });
  }
  // metalOrderManageList(queryParams.value).then((response) => {
  //   orderList.value = response.rows;
  //   page.value.total = response.total;
  //   loading.value = false;
  // });
  // axios
  //   .all([
  //     /** 查询工厂列表 */
  //     listAll_plant({}),
  //     /** 查询车间列表 */
  //     listAll_shop({}),
  //   ])
  //   .then(
  //     axios.spread((response1, response2) => {
  //       plantList.value = response1.data;
  //       shopList.value = response2.data;
  //       loading.value = false;
  //     })
  //   )
  //   .catch((error) => {
  //     console.error("请求出错:", error);
  //   });
}
/** 搜索按钮操作 */
function handleQuery() {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}
function changePageNo(currentPage) {
  queryParams.value.pageNum = currentPage;
  page.value.current = currentPage;
  getList();
}
function changePageSize(pageSize) {
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  queryParams.value.pageSize = pageSize;
  getList();
}
// 多选框选中数据
const handleCheckboxChange = (data) => {
  console.log(data, "handleCheckboxChange");
  ids.value = data.records.map((item) => item.id);
  single.value = data.records.length !== 1;
  multiple.value = !data.records.length;
  subUpdateList.value = data.records;
};
onMounted(() => {
  getList();
});
</script>
<style lang="scss" scoped>
.column-with-margin {
  margin-right: 0px;
}
.mode_box {
  margin-left: 30px;
  margin-bottom: 10px;
  & span {
    padding-right: 20px;
  }
}
.red_color {
  color: #f56c6c;
  margin-bottom: 10px;
}
.mart5 {
  margin-top: 5px;
}
</style>
